@@ -132,9 +132,19 @@ from ptah import cms
 # form api
 from ptah import form
 
+# populate
+POPULATE = False
+from ptah.populate import populate
+from ptah.populate import POPULATE_DB_SCHEMA
+
 # simple test case
 from ptah.testing import PtahTestCase
 
+# register migration
+from ptah.migrate import register_migration
+
+register_migration('ptah', 'ptah:migrations', 'Ptah database migration', True)
+
 
 def includeme(cfg):
     # auth
@@ -159,10 +169,12 @@ def includeme(cfg):
 
     # initialize settings
     from ptah import settings
+    from pyramid.interfaces import PHASE1_CONFIG
     def pyramid_init_settings(cfg, custom_settings=None,
                               section=configparser.DEFAULTSECT):
         cfg.action('ptah.init_settings',
-                   settings.init_settings, (cfg, custom_settings, section))
+                   settings.init_settings,
+                   (cfg, custom_settings, section), order=999999)
 
     cfg.add_directive('ptah_init_settings', pyramid_init_settings)
 
@@ -212,6 +224,20 @@ def includeme(cfg):
     # snippet directive
     cfg.add_directive('ptah_snippet', snippet.pyramid)
 
+    # populate
+    def pyramid_populate(cfg):
+        from ptah.populate import Populate
+        if not POPULATE:
+            cfg.action('ptah.populate',
+                       Populate(cfg.registry).execute, order=9999999)
+
+    cfg.add_directive('ptah_populate', pyramid_populate)
+    cfg.add_directive('ptah_populate_step', populate.pyramid)
+
+    # migrations
+    from ptah import migrate
+    cfg.add_directive('ptah_migrate', migrate.ptah_migrate)
+
     # ptah static assets
     cfg.add_static_view('_ptah/static', 'ptah:static/')
 
