@@ -47,6 +47,10 @@ class Node(ptah.get_base()):
        a :py:class:`ptah.JsonListType` of :py:class:`ptah.ACL` strings
        registered with security machinery.
 
+    .. attribute:: __annotations__
+
+       a dictionary which contains strings arbitrary annotations data.
+
     .. attribute:: __uri_factory__
 
        function which will return value for __uri__.  the uri must be
@@ -57,19 +61,19 @@ class Node(ptah.get_base()):
     __tablename__ = 'ptah_nodes'
 
     __id__ = sqla.Column('id', sqla.Integer, primary_key=True)
-    __type_id__ = sqla.Column('type', sqla.String, info={'uri':True})
+    __type_id__ = sqla.Column('type', sqla.String(128), info={'uri':True})
     __type__ = None
 
-    __uri__ = sqla.Column('uri', sqla.String, unique=True,
+    __uri__ = sqla.Column('uri', sqla.String(255), unique=True,
                           nullable=False, info={'uri':True})
-    __parent_uri__ = sqla.Column('parent',
-                                 sqla.String,sqla.ForeignKey(__uri__),
-                                 info={'uri': True})
+    __parent_uri__ = sqla.Column('parent', sqla.String(255),
+                                 sqla.ForeignKey(__uri__), info={'uri': True})
 
-    __owner__ = sqla.Column('owner',
-                            sqla.String, default=text_type(''), info={'uri':True})
+    __owner__ = sqla.Column('owner', sqla.String(255),
+                            default='', info={'uri':True})
     __local_roles__ = sqla.Column('roles', ptah.JsonDictType(), default={})
     __acls__ = sqla.Column('acls', ptah.JsonListType(), default=[])
+    __annotations__ = sqla.Column('annotations', ptah.JsonDictType(),default={})
 
     __children__ = sqla.orm.relationship(
         'Node',
