@@ -104,3 +104,10 @@ class IACLsAware(interface.Interface):
     """ acl maps aware context """
 
     __acls__ = interface.Attribute('List of acl map ids')
+
+
+def populate_step(registry):
+    """ Populate data step.
+
+    :param registry: Pyramid :py:class:`pyramid.registry.Registry` object
+    """
